@@ -11,6 +11,6 @@ class CreatedAtColumn(Column):
     def __str__(self):
         ''' Returns a string in the form of a MySQL column '''
         
-        sql = 'created_at TIMESTAMP NOT NULL DEFAULT {default}'.format(default=self.default)
+        sql = 'created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP()'
         
         return sql
\ No newline at end of file
