@@ -13,9 +13,9 @@ class Database():
         self.user = os.getenv('DB_USER')
         self.password = os.getenv('DB_PASS')
         self.mysql_config = {
+            'host': '170-187-194-33.ip.linodeusercontent.com',
             'user': os.getenv('DB_USER'),
             'password': os.getenv('DB_PASS'),
-            'host': os.getenv('DB_HOST'),
             'port': '3306',
             'ssl_disabled': True
         }
