@@ -27,4 +27,4 @@ class PaymentsTable(Table):
 		]
     
     def get_create_table_sql(self):
-        super().create_table_sql()
\ No newline at end of file
+        return super(PaymentsTable, self).get_create_table_sql()
\ No newline at end of file
